@@ -576,9 +576,16 @@ class PeerManager:
                 self.am_interested = False
                 self.send_message(MexType.NOT_INTERESTED)
             return
-        
+
+        if not self.am_interested:
+            self.logger.warning("Want to ask piece, but I'm not interested? Sending INTERESTED", )
+            self.am_interested = True
+            self.send_message(MexType.INTERESTED)
+            if self.peer_chocking:
+                return # wait for unchoke
+
         if self.peer_chocking:
-            self.logger.debug("Wanted to ask a new piece, but am choked")
+            self.logger.debug("Wanted to ask a new piece, but am choked")    
             return
 
         not_yet_started = set(self.am_interested_in) - set(self.my_progresses.keys())
@@ -594,13 +601,7 @@ class PeerManager:
             self.logger.debug("Already downloading at the fullest")
             return
 
-        if not self.am_interested:
-            self.logger.warning("Want to ask piece, but I'm not interested? Sending INTERESTED", )
-            self.am_interested = True
-            self.send_message(MexType.INTERESTED)
-            if self.peer_chocking:
-                return # wait for unchoke
-            
+        
         random_piece = random.sample(
             list(not_yet_started), #non si può fare random choice su set()
             k=min(self.max_concurrent_pieces - len(self.my_progresses),
@@ -849,14 +850,14 @@ class ThreadedServer:
         self.port = self.sock.getsockname()[1]
         self.logger.debug("Self port: %d", self.port)
 
-        self.peers = list()
+        self.peers = self.options.get("suggested_peers", [])
         peers = self.tracker_manager.notify_start()
-        for ip, pport in peers:
+        for ip, pport in peers: #filters myself
             if ip in ["localhost", utils.get_external_ip()]:
-                if port == pport:
+                if self.port == pport:
                     continue
             self.peers.append((ip, pport))
-            
+        
         # La bitmap iniziale, quando il programma viene avviato.
         # Viene letta da un file salvato in sessioni precedenti, oppure
         # creata ad hoc.
@@ -866,7 +867,7 @@ class ThreadedServer:
             num_pieces=self.metainfo.num_pieces
         )
         
-        self.max_peer_connections = 2
+        self.max_peer_connections = 1
         self.active_connections = set()
         
         self.mcu = master.MasterControlUnit(self.metainfo, self.global_bitmap, self.options)
@@ -881,7 +882,10 @@ class ThreadedServer:
 
         self.mcu.main()
         
-        print(self.peers)
+        print("Available peers:", self.peers)
+        if self.peers == []:
+            self.logger.debug("No peers currently available")
+            return
         
         i = 0
         while i < min(self.max_peer_connections, len(self.peers)):
@@ -967,25 +971,27 @@ import Fiume.metainfo_decoder as md
 import bencodepy
 import argparse
 
-# options = {
-#     "torrent_path": pathlib.Path("/home/groucho/Un gioco di specchi.mp4.torrent"),
-#     "output_file":  pathlib.Path("/home/groucho/torrent/downloads/film.mp4"),
-#     "delay": 0,
-#     "debug": False,
-#     "debug-level": logging.WARNING
-# }
+if __name__ == "__main__":
+    options = {
+        "torrent_path": pathlib.Path("/home/groucho/torrent/image.jpg.torrent"),
+        "output_file":  pathlib.Path("/home/groucho/torrent/downloads/image.jpg"),
+        "delay": 0,
+        "debug": False,
+        "debug-level": logging.WARNING,
+        "port": 50146,
+        "suggested_peers": [("78.14.24.41", 50144)]
+    }
 
-# with open(options["torrent_path"], "rb") as f:
-#     metainfo = md.MetaInfo(
-#         bencodepy.decode(f.read()) | options
-#     )
+    with open(options["torrent_path"], "rb") as f:
+        metainfo = md.MetaInfo(
+            bencodepy.decode(f.read()) | options
+        )
 
-# tm = md.TrackerManager(metainfo, options)
+    tm = md.TrackerManager(metainfo, options)
 
-# t = ThreadedServer(
-#     50146,
-#     metainfo, tm,
-#     **options
-# )
+    t = ThreadedServer(
+        metainfo, tm,
+        **options
+    )
 
-# t.main()
+    t.main()
